@@ -1,3 +1,12 @@
+// Copyright 2021 MaidSafe.net limited.
+//
+// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
+// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
+// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
+// modified, or distributed except according to those terms. Please review the Licences for the
+// specific language governing permissions and limitations relating to use of the SAFE Network
+// Software.
+
 use crate::{Config, QuicP2p};
 use anyhow::Result;
 use bytes::Bytes;
@@ -29,7 +38,7 @@ pub fn new_qp2p_with_hcc(hard_coded_contacts: HashSet<SocketAddr>) -> Result<Qui
     Ok(qp2p)
 }
 
-pub fn random_msg() -> Bytes {
-    let random_bytes: Vec<u8> = (0..1024).map(|_| rand::random::<u8>()).collect();
+pub fn random_msg(size: usize) -> Bytes {
+    let random_bytes: Vec<u8> = (0..size).map(|_| rand::random::<u8>()).collect();
     Bytes::from(random_bytes)
 }
